<?php
$TRANSLATIONS = array(
"Contacts" => "Επαφές",
"Add new LDAP Addressbook" => "Προσθήκη νέου βιβλίου διευθύνσεων LDAP",
"Ok" => "Οκ",
"Cancel" => "Άκυρο",
"Save" => "Αποθήκευση",
"Edit Addressbook" => "Επεξεργασία βιβλίου διευθύνσεων",
"Import contacts" => "Εισαγωγή επαφών",
"Upload file..." => "Μεταφόρτωση αρχείου...",
"Starting file import" => "Έναρξη εισαγωγής αρχείου",
"Format selected: {format}" => "Επιλεγμένη μορφοποίηση: {format}",
"Automatic format detection" => "Αυτόματη ανίχνευση μορφοποίησης",
"Import into..." => "Εισαγωγή σε...",
"Processing {count}/{total} cards" => "Επεξεργασία {count}/{total} καρτών",
"Total: {total}, Success: {imported}, Errors: {failed}" => "Σύνολο: {total}, Επιτυχείς: {imported}, Σφάλματα: {failed}",
"An address book called {name} already exists" => "Το βιβλίο διευθύνσεων με το όνομα {name} υπάρχει ήδη ",
"Failed adding address book: {error}" => "Αποτυχία πρόσθεσης βιβλίου διευθύνσεων: {error}",
"Failed loading address books: {error}" => "Αποτυχία φόρτωσης βιβλίων διευθύνσεων: {error}",
"Server error! Please inform system administator" => "Σφάλμα διακομιστή! Παρακαλώ ενημερώστε το διαχειριστή",
"Indexing contacts" => "Ευρετηρίαση επαφών",
"Unrecoverable error loading address books: {msg}" => "Ανεπανόρθωτο σφάλμα κατά τη φόρτωση των βιβλίων διευθύνσεων: {msg}",
"Error." => "Σφάλμα.",
"Add to..." => "Προσθήκη στο...",
"Remove from..." => "Αφαίρεση από το...",
"Add group..." => "Προσθήκη ομάδας...",
"Invalid URL: \"{url}\"" => "Μη έγκυρη URL: \"{url}\"",
"Invalid email: \"{url}\"" => "Μη έγκυρο email: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Αποτυχία συγχώνευσης. Αδυναμία εύρεσης επαφής: {id}",
"Merge failed." => "Η συγχώνευση απέτυχε. ",
"Merge failed. Error saving contact." => "Αποτυχία συγχώνευσης. Σφάλμα αποθήκευσης επαφής.",
"Select photo" => "Επέλεξε φωτογραφία",
"Network or server error. Please inform administrator." => "Σφάλμα δικτύου ή διακομιστή. Παρακαλώ ενημερώστε το διαχειριστή.",
"Only images can be used as contact photos" => "Μόνο αρχεία εικόνας μπορούν να χρησιμοποιηθούν σαν φωτογραφίες επαφών",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "Το μέγεθος του \"{filename}\" υπερβαίνει το μέγιστο επιτρεπόμενο {size}",
"Error adding to group." => "Σφάλμα κατά την προσθήκη σε ομάδα.",
"Error removing from group." => "Σφάλμα κατά την αφαίρεση από ομάδα.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Έχετε επιλέξει πάνω από 300 επαφές.\nΑυτό μάλλον θα αποτύχει! Κλικάρετε εδώ για να δοκιμάσετε ούτως ή άλλως.",
"Error setting {name} as favorite." => "Σφάλμα κατά τον ορισμό του {name} σαν αγαπημένο.",
"Merge contacts" => "Συγχώνευση επαφών",
"Add group" => "Προσθήκη ομάδας",
"OK" => "ΟΚ",
"Could not find contact: {id}" => "Αδυναμία εύρεσης επαφής: {id}",
"Edit profile picture" => "Επεξεργασία εικόνας προφίλ",
"Crop photo" => "Περικοπή φωτογραφίας",
"Error parsing date: {date}" => "Σφάλμα κατά την ανάλυση της ημερομηνίας: {date}",
"# groups" => "# ομάδων",
"Error parsing birthday {bday}" => "Σφάλμα κατά την ανάλυση των γενεθλίων {bday}",
"The backend does not support multi-byte characters." => "Το σύστημα δεν υποστηρίζει χαρακτήρες πολλών byte",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Κάποιες επαφές σημειώθηκαν προς διαγραφή αλλά δεν έχουν διαγραφεί ακόμα. Παρακαλώ περιμένετε μέχρι να διαγραφούν.",
"Click to undo deletion of {num} contacts" => "Επιλέξτε για να αναιρέσετε τη διαγραφή {num} επαφών",
"Cancelled deletion of {num} contacts" => "Αναιρέθηκε η διαγραφή {num} επαφών",
"Add" => "Προσθήκη",
"Contact is already in this group." => "Η επαφή είναι ήδη σε αυτήν την ομάδα.",
"Contacts are already in this group." => "Οι επαφές είναι ήδη σε αυτήν την ομάδα.",
"Couldn't get contact list." => "Αδυναμία λήψης λίστας επαφών.",
"Contact is not in this group." => "Η επαφή δεν είναι σε αυτή την ομάδα.",
"Contacts are not in this group." => "Οι επαφές δεν είναι σε αυτήν την ομάδα.",
"A group named \"{group}\" already exists" => "Μια ομάδα με το όνομα \"{group}\" υπάρχει ήδη",
"Failed renaming group: {error}" => "Σφάλμα μετονομασίας της ομάδας: {error}",
"Failed adding group: {error}" => "Σφάλμα προσθήκης της ομάδας: {error}",
"All" => "Όλες",
"Favorites" => "Αγαπημένες",
"Shared by {owner}" => "Διαμοιράστηκε από τον {owner}",
"Not grouped" => "Οχι ομαδοποιημένα",
"Failed loading groups: {error}" => "Σφάλμα φόρτωσης της ομάδας: {error}",
"Please choose the addressbook" => "Παρακαλώ επιλέξτε το βιβλίο διευθύνσεων",
"Error loading import template" => "Σφάλμα φόρτωσης προτύπου",
"Import" => "Εισαγωγή",
"Importing..." => "Γίνεται εισαγωγή...",
"Import done" => "Η εισαγωγή ολοκληρώθηκε",
"Close" => "Κλείσιμο",
"Contact" => "Επαφή",
"Error, missing parameters: " => "Σφάλμα, ελλιπείς παράμετροι:",
"Failed loading photo: {error}" => "Αποτυχία φόρτωσης φωτογραφίας: {error}",
"You do not have permissions to see this contact" => "Δεν έχετε άδεια να δείτε αυτή την επαφή",
"Contact not found" => "Δεν βρέθηκε επαφή",
"You do not have permissions to see these contacts" => "Δεν έχετε άδεια για να δείτε αυτές τις επαφές",
"You do not have permissions add contacts to the address book" => "Δεν έχετε άδεια για να προσθέσετε επαφές σε αυτό το βιβλίο διευθύνσεων.",
"The backend for this address book does not support adding contacts" => "Το σύστημα για αυτό το βιβλίο διευθύνσεων δεν υποστηρίζει την προσθήκη επαφών.",
"You do not have permissions to delete this contact" => "Δεν έχετε άδεια για τη διαγραφή αυτής της επαφής",
"The backend for this address book does not support deleting contacts" => "Το σύστημα για αυτό το βιβλίο διευθύνσεων δεν υποστηρίζει τη διαγραφή επαφών",
"Unknown error" => "Άγνωστο σφάλμα",
"Access denied" => "Δεν επιτρέπεται η πρόσβαση",
"The backend for this address book does not support updating" => "Το σύστημα για αυτό το βιβλίο διευθύνσεων δεν υποστηρίζει ενημέρωση ",
"You don't have permissions to delete the address book." => "Δεν έχετε άδεια να διαγράψετε το βιβλίο διευθύνσεων.",
"Address book not found" => "Δε βρέθηκε βιβλίο διευθύνσεων",
"You do not have permissions to update this contact" => "Δεν έχετε άδεια για να ενημερώσετε αυτή την επαφή",
"The backend for this contact does not support updating it" => "Το σύστημα για αυτή την επαφή δεν υποστηρίζει την ενημέρωσή της",
"This backend does not support adding contacts" => "Αυτό το σύστημα δεν υποστηρίζει προσθήκη επαφών",
"Property not found" => "H ιδιότητα δεν βρέθηκε",
" Missing IM parameter for: " => "Λείπει παράμετρος AM για:",
"Unknown IM: " => "Άγνωστο AM:",
"{name}'s Birthday" => "Τα γενέθλια του/της {name}",
"Error creating address book" => "Σφάλμα κατά την δημιουργία βιβλίου διευθύνσεων ",
"The \"%s\" backend does not support deleting address books" => "Το σύστημα \"%s\" δεν υποστηρίζει τη διαγραφή βιβλίων διευθύνσεων",
"You do not have permissions to delete the \"%s\" address book" => "Δεν έχετε άδεια να διαγράψετε το βιβλίο διευθύνσεων \"%s\"",
"Error deleting address book" => "Σφάλμα κατά την διαγραφή βιβλίου διεευθύνσεων ",
"Error creating contact." => "Σφάλμα δημιουργίας επαφής.",
"Error creating contact" => "Σφάλμα δημιουργίας επαφής",
"Error deleting contact" => "Σφάλμα διαγραφής επαφής",
"Error retrieving contact" => "Σφάλμα κατά την ανάκτηση της επαφής",
"Error saving contact" => "Σφάλμα αποθήκευσης επαφής",
"Error removing contact from other address book." => "Σφάλμα διαγραφής επαφής από άλλο βιβλίο διευθύνσεων.",
"Error getting moved contact" => "Σφάλμα κατά την λήψη μετακινημένης επαφής",
"Couldn't find contact." => "Αδυναμία εύρεσης επαφής.",
"No contact data in request." => "Δεν υπάρχουν δεδομένα επαφής στο αίτημα.",
"Error merging into contact." => "Σφάλμα κατά τη συγχώνευση με επαφή. ",
"Error saving contact to backend." => "Σφάλμα κατά την αποθήκευση επαφής στο σύστημα. ",
"Property name is not set." => "Δεν ορίστηκε η ιδιότητα όνομα. ",
"Property checksum is not set." => "Δεν ορίστηκε η ιδιότητα άθροισμα ελέγχου.",
"Information about vCard is incorrect. Please reload the page." => "Οι πληροφορίες σχετικά με τη vCard είναι εσφαλμένες. Παρακαλώ επαναφορτώστε τη σελίδα.",
"Error updating contact" => "Σφάλμα κατά την ενημέρωση επαφής ",
"Error saving contact to backend" => "Σφάλμα κατά την αποθήκευση επαφής στο σύστημα",
"No photo path was submitted." => "Δεν δόθηκε διαδρομή εικόνας",
"Error loading image from cache" => "Σφάλμα κατά την φόρτωση της εικόνας από την προσωρινή μνήμη",
"Error getting PHOTO property." => "Σφάλμα κατά τη λήψη ιδιοτήτων ΦΩΤΟΓΡΑΦΙΑΣ.",
"Error saving contact." => "Σφάλμα κατά την αποθήκευση επαφής.",
"No group name given." => "Δεν δόθηκε όνομα ομάδας.",
"Error adding group." => "Σφάλμα κατά την προσθήκη ομάδας.",
"No group ID given." => "Δεν δόθηκε ID ομάδας.",
"No group name to rename from given." => "Κανένα όνομα ομάδας για μετονομασία από το δοθέν.",
"No group name to rename to given." => "Κανένα όνομα ομάδας για μετονομασία στο δοθέν.",
"Error renaming group." => "Σφάλμα κατά τη μετονομασία της ομάδας",
"Group ID missing from request." => "Το ID ομάδας λείπει από το αίτημα.",
"Group name missing from request." => "Το όνομα ομάδας λείπει από το αίτημα.",
"Contact ID missing from request." => "Το ID επαφής λείπει από το αίτημα.",
"No file was uploaded. Unknown error" => "Δεν μεταφορτώθηκε κάποιο αρχείο. Άγνωστο σφάλμα",
"There is no error, the file uploaded with success" => "Δεν υπάρχει σφάλμα, το αρχείο μεταφορτώθηκε επιτυχώς",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Το αρχείο που μεταφορτώθηκε υπερβαίνει την οδηγία μέγιστου επιτρεπτού μεγέθους \"upload_max_filesize\" του php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Το αρχείο που μεταφορτώθηκε υπερβαίνει την οδηγία MAX_FILE_SIZE που ορίζεται στην φόρμα HTML",
"The uploaded file was only partially uploaded" => "Το αρχείο μεταφορτώθηκε μόνο εν μέρει",
"No file was uploaded" => "Κανένα αρχείο δεν μεταφορτώθηκε",
"Missing a temporary folder" => "Λείπει ένας προσωρινός φάκελος",
"Failed to write to disk" => "Αποτυχία εγγραφής στο δίσκο",
"Not enough storage available" => "Ανεπαρκής διαθέσιμος αποθηκευτικός χώρος",
"Attempt to upload blacklisted file:" => "Προσπάθεια μεταφόρτωσης αρχείου που βρίσκεται στη μαύρη λίστα:",
"Error uploading contacts to storage." => "Σφάλμα κατά την μεταφόρτωση επαφών",
"Error moving file to imports folder." => "Σφάλμα μετακίνησης αρχείου στο φάκελο εισαγωγών.",
"You do not have permissions to import into this address book." => "Δεν έχετε άδεια για εισαγωγή σε αυτό το βιβλίο διευθύνσεων.",
"File name missing from request." => "Το όνομα αρχείου λείπει από το αίτημα.",
"Progress key missing from request." => "Το κλειδί προόδου λείπει από το αίτημα.",
"Attempt to access blacklisted file:" => "Προσπάθεια πρόσβασης αρχείου που βρίσκεται στη μαύρη λίστα:",
"No key is given." => "Δεν δόθηκε κλειδί.",
"No value is given." => "Δεν δόθηκε τιμή.",
"Could not set preference: " => "Αδυναμία ορισμού προτίμησης:",
"Other" => "Άλλο",
"HomePage" => "Αρχική Σελίδα",
"Jabber" => "Jabber",
"Internet call" => "Κλήση Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Εργασία",
"Home" => "Σπίτι",
"Mobile" => "Κινητό",
"Text" => "Κείμενο",
"Voice" => "Ομιλία",
"Message" => "Μήνυμα",
"Fax" => "Φαξ",
"Video" => "Βίντεο",
"Pager" => "Βομβητής",
"Internet" => "Διαδίκτυο",
"Friends" => "Φίλοι",
"Family" => "Οικογένεια",
"Enable LDAP Backend" => "Ενεργοποίηση συστήματος LDAP",
"Enable LDAP backend for the contacts application" => "Ενεργοποίηση συστήματος LDAP για την εφαρμογή επαφών",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Προσοχή: Το σύστημα LDAP είναι σε δοκιμαστική φάση, χρησιμοποιείτε με επιφύλαξη",
"New contact" => "Νέα επαφή",
"Group name" => "Όνομα ομάδας",
"New group" => "Νέα ομάδα",
"Address books" => "Βιβλία Διευθύνσεων",
"Display name" => "Προβαλλόμενο όνομα",
"Add Address Book" => "Προσθήκη Βιβλίου Διευθύνσεων",
"Add LDAP Address Book" => "Προσθήκη βιβλίου διευθύνσεων LDAP",
"(De-)select all" => "(Απο-)επιλογή όλων",
"Sort order" => "Σειρά ταξινόμησης",
"First- Lastname" => "Όνομα- Επίθετο",
"Last-, Firstname" => "Επίθετο-, Όνομα",
"Delete" => "Διαγραφή",
"Groups" => "Ομάδες",
"Download" => "Λήψη",
"Merge" => "Συγχώνευση",
"Email" => "Ηλ. ταχυδρομείο",
"Phone" => "Τηλέφωνο",
"Address" => "Διεύθυνση",
"Group" => "Ομάδα",
"Keyboard shortcuts" => "Συντομεύσεις πλητρολογίου",
"Navigation" => "Πλοήγηση",
"Next contact in list" => "Επόμενη επαφή στη λίστα",
"Previous contact in list" => "Προηγούμενη επαφή στη λίστα",
"Expand/collapse current addressbook" => "Ανάπτυξη/σύμπτυξη τρέχοντος βιβλίου διευθύνσεων",
"Next addressbook" => "Επόμενο βιβλίο διευθύνσεων",
"Previous addressbook" => "Προηγούμενο βιβλίο διευθύνσεων",
"Actions" => "Ενέργειες",
"Refresh contacts list" => "Ανανέωση λίστας επαφών",
"Add new contact" => "Προσθήκη νέας επαφής",
"Add new addressbook" => "Προσθήκη νέου βιβλίου επαφών",
"Delete current contact" => "Διαγραφή τρέχουσας επαφής",
"You have no contacts in your address book or your address book is disabled." => "Δεν έχετε καθόλου επαφές στο βιβλίο διευθύνσεών σας ή το βιβλίο διευθύνσεων σας είναι απενεργοποιημένο.",
"Add a new contact or import existing contacts from a file (VCF, CSV or LDIF)." => "Προσθέστε μια νέα επαφή ή εισαγάγετε υπάρχουσες επαφές από ένα αρχείο (VCF, CSV ή LDIF).",
"Which contact should the data be merged into?" => "Με ποιά επαφή θα θέλατε να συγχωνευτούν τα δεδομένα?",
"Delete the other(s) after successful merge?" => "Διαγραφή του(ων) άλλου(ων) μετά την επιτυχή συγχώνευση?",
"Compose mail" => "Σύνθεση μηνύματος",
"Delete current photo" => "Διαγραφή τρέχουσας φωτογραφίας",
"Edit current photo" => "Επεξεργασία τρέχουσας φωτογραφίας",
"Upload new photo" => "Μεταφόρτωση νέας φωτογραφίας",
"Select photo from Files" => "Επιλογή φωτογραφίας από τα Αρχεία",
"Favorite" => "Αγαπημένο",
"Name" => "Όνομα",
"First name" => "Όνομα",
"Additional names" => "Επιπλέον ονόματα",
"Last name" => "Επώνυμο",
"Address book" => "Βιβλίο διευθύνσεων",
"Nickname" => "Παρατσούκλι",
"Title" => "Τίτλος",
"Organization" => "Οργανισμός",
"Birthday" => "Γενέθλια",
"Website" => "Ιστοσελίδα",
"Instant messaging" => "Άμεσα μηνύματα",
"Notes go here..." => "Πρόσθεσε τις σημειώσεις εδώ...",
"Add field..." => "Προσθήκη πεδίου...",
"Instant Messaging" => "Άμεσα μηνύματα",
"Note" => "Σημείωση",
"Web site" => "Ιστότοπος",
"Preferred" => "Προτιμώμενο",
"Please specify a valid email address." => "Παρακαλώ εισάγετε μια έγκυρη διεύθυνση ηλεκτρονικού ταχυδρομείου",
"someone@example.com" => "someone@example.com",
"Mail to address" => "Αποστολή σε διεύθυνση",
"Delete email address" => "Διαγραφή διεύθυνσης ηλ. ταχυδρομείου",
"Enter phone number" => "Εισάγετε αριθμό τηλεφώνου",
"Go to web site" => "Πήγαινε στον ιστότοπο",
"View on map" => "Προβολή στο χάρτη",
"Street address" => "Διεύθυνση οδού",
"Postal code" => "Ταχυδρομικός Κωδικός",
"City" => "Πόλη",
"State or province" => "Νομός ή περιφέρεια",
"Country" => "Χώρα",
"Instant Messenger" => "Εφαρμογή Άμεσων Μηνυμάτων",
"Active" => "Ενεργό",
"Share" => "Διαμοιρασμός",
"Export" => "Εξαγωγή",
"CardDAV link" => "Σύνδεσμος CardDAV",
"Edit" => "Επεξεργασία",
"Format" => "Μορφοποίηση",
"Automatic format" => "Αυτόματη μορφοποίηση",
"Select file..." => "Επιλογή αρχείου...",
"Addressbook URI" => "Διεύθυνση URI βιβλίου διευθύνσεων",
"URI" => "Διεύθυνση URI",
"Description" => "Περιγραφή",
"LDAP URL" => "Διεύθυνση URL LDAP",
"Anonymous" => "Ανώνυμος",
"Read-only" => "Μόνο για ανάγνωση",
"Read-Only" => "Μόνο για ανάγνωση",
"User" => "Χρήστης",
"Password" => "Κωδικός πρόσβασης",
"Page size" => "Μέγεθος σελίδας",
"Base DN for search" => "Αρχικό ΔΟ για αναζήτηση",
"Base DN" => "Αρχικό ΔΟ",
"Search filter" => "Φίλτρο αναζήτησης",
"Filter" => "Φίλτρο",
"Base DN for modification" => "Αρχικό ΔΟ για μεταβολή",
"Base DN modification" => "Μεταβολή αρχικού ΔΟ",
"Connector" => "Σύνδεσμος",
"Connector value (Better use external editor and copy/paste)" => "Μεταβλητή συνδέσμου (Καλύτερα χρησιμοποιείστε εξωτερικό επεξεργαστή και αντιγράψτε/επικολλήστε)",
"Copy from (Warning, replaces current custom value)" => "Αντιγραφή από (Προσοχή, αντικαθιστά την τρέχουσα προσαρμοσμένη τιμή)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
